==> pimd_2.3.1.orig.tar.gz: pimd-2.3.1/libite/chomp.c <==
/* Perl inspired chomp() implementation.
 *
 * Copyright (c) 2014-2015  Joachim Nilsson <troglobit@gmail.com>
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#include <errno.h>
#include <string.h>

/**
 * chomp - Perl like chomp function, chop off last char(s) if newline.
 * @str: String to chomp
 *
 * This function is like Perl chomp, but it's set to chop of all
 * trailing newlines.
 *
 * Returns:
 * If @str is a valid pointer this function returns @str, otherwise
 * @errno is set to %EINVAL and this function returns %NULL.
 */
char *chomp(char *str)
{
	char *p;

	if (!str || strlen(str) < 1) {
		errno = EINVAL;
		return NULL;
	}

	p = str + strlen(str) - 1;
        while (*p == '\n')
		*p-- = 0;

	return str;
}

#ifdef UNITTEST
#include <stdio.h>
int main(void)
{
	int i; char t[][16] = { "hej\ndej", "Slime\n\n\\n", "Tripple\n\n\n", "" };
	for (i = 0; t[i][0]; i++) printf("'%s'\n", chomp(t[i])); return 0;
}
#endif

/**
 * Local Variables:
 *  compile-command: "gcc -DUNITTEST -o chompy chomp.c && ./chompy"
 *  version-control: t
 *  indent-tabs-mode: t
 *  c-file-style: "linux"
 * End:
 */

==> pimd_2.3.2.orig.tar.gz: pimd-2.3.2/libite/chomp.c <==
/* Perl inspired chomp() implementation.
 *
 * Copyright (c) 2014-2015  Joachim Nilsson <troglobit@gmail.com>
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#include <errno.h>
#include <string.h>

/**
 * chomp - Perl like chomp function, chop off last char(s) if newline.
 * @str: String to chomp
 *
 * This function is like Perl chomp, but it's set to chop of all
 * trailing newlines.
 *
 * Returns:
 * If @str is a valid pointer this function returns @str, otherwise
 * @errno is set to %EINVAL and this function returns %NULL.
 */
char *chomp(char *str)
{
	char *p;

	if (!str || strlen(str) < 1) {
		errno = EINVAL;
		return NULL;
	}

	p = str + strlen(str) - 1;
        while (*p == '\n')
		*p-- = 0;

	return str;
}

#ifdef UNITTEST
#include <stdio.h>
int main(void)
{
	int i; char t[][16] = { "hej\ndej", "Slime\n\n\\n", "Tripple\n\n\n", "" };
	for (i = 0; t[i][0]; i++) printf("[%02d]: '%s'\n", i, chomp(t[i])); return 0;
}
#endif

/**
 * Local Variables:
 *  compile-command: "make V=1 -f chomp.mk"
 *  version-control: t
 *  indent-tabs-mode: t
 *  c-file-style: "linux"
 * End:
 */
